package com.zehong.communication.common.interceptor;

import com.zehong.communication.common.result.Result;
import com.zehong.communication.common.result.ResultEnum;
import com.zehong.communication.util.IPUtils;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.core.annotation.Order;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;

@Order(0)
@Aspect
@Component
public class AopInterceptor {

    private static final Logger logger = LoggerFactory.getLogger(AopInterceptor.class);

    @Value("${iPWhite}")
    private String iPWhite;

    /**
     * 定义拦截器规则
     */

    @Pointcut("execution(* com.zehong.communication.controller.*.*(..))")
    public void pointCut() {
    }

    /**
     * 拦截器具体实现
     *
     * @throws Throwable
     */
    @Around(value = "pointCut()")
    public Object around(ProceedingJoinPoint point) throws Throwable {
        try {
            HttpServletRequest request = ((ServletRequestAttributes) RequestContextHolder.getRequestAttributes()).getRequest();
            //判断是否为黑名单用户
            String ip = IPUtils.getIpAddress(request);
            if (checkIpWhite(ip)) {
                logger.info("当前请求ip:" + ip +",在白名单名单中");
                return point.proceed();
            } else {
                //ip不在黑名单中返回true
                logger.info( "当前请求ip:" + ip + ",不存在白名单中，拒绝访问");
                return new Result(ResultEnum.NOT_IN_IPWHITE);
            }
        } catch (Exception e) {
            logger.error("白名单拦截出错:"+e);
            return new Result(ResultEnum.SYSTEM_EXCEPTION);
        }
    }

    /**
     * 对比白名单IP
     * @param ip 请求ip
     * @return
     * @throws Exception
     */
    public boolean checkIpWhite(String ip) throws Exception {
        String[] ipWhites = iPWhite.split(",");
        for(String whiteIp : ipWhites){
            if(whiteIp.equals(ip)){
                return true;
            }
        }
        return false;
    }

}
