package com.zehong.communication.controller;

import com.zehong.communication.common.result.Result;
import com.zehong.communication.common.result.ResultEnum;
import com.zehong.communication.model.SendBatchVoiceNotify;
import com.zehong.communication.model.SendVoiceNotify;
import com.zehong.communication.service.VoiceNotifyService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.io.IOException;
import java.net.URISyntaxException;

/**
 *发送语音
 * @author gengdidi
 */
@RestController
@RequestMapping("/voiceNotify")
public class VoiceNotifyController {
    private static final Logger logger = LoggerFactory.getLogger(VoiceNotifyController.class);

    @Autowired
    private VoiceNotifyService voiceNotifyService;

    /**
     * 发送语音 被叫号码，限单个，仅支持11位国内号码
     * @param sendVoiceNotify 发送语音实体
     * @return String
     */
    @RequestMapping(value = "/sendVoiceNotify",method = RequestMethod.POST)
    public Result sendVoiceNotify(@Valid @RequestBody SendVoiceNotify sendVoiceNotify, BindingResult result){
        try {
            if(result.hasErrors()){
                return new Result(ResultEnum.VALIDATA_ERROR.getCode(),result.getFieldError().getDefaultMessage());
            }
            return voiceNotifyService.sendVoiceNotify(sendVoiceNotify);
        } catch (IOException | URISyntaxException e) {
            logger.info("语音发送失败！phoneNumber:%",sendVoiceNotify.getPhoneNumber(),e);
            return new Result(ResultEnum.SYSTEM_EXCEPTION);
        }
    }

    /**
     *批量发送语音 被叫号码，模版无变量多个则以英文半角分号“;”分割；模板带变量，多个号码以英文分号“;”分割，号码和变量以英文逗号“,”隔开， 多个变量以竖线“|”隔开，如 130XXXXXXXX,123|456;186XXXXXXXX,321|654(注意：文件语音模板类型 号码之间分隔用“,”隔开)
     * @param sendBatchVoiceNotify 批量发送语音实体
     * @return String
     */
    @RequestMapping(value = "/sendBatchVoiceNotify",method = RequestMethod.POST)
    public Result sendBatchVoiceNotify(@Valid @RequestBody SendBatchVoiceNotify sendBatchVoiceNotify, BindingResult result){
        try {
            if(result.hasErrors()){
                return new Result(ResultEnum.VALIDATA_ERROR.getCode(),result.getFieldError().getDefaultMessage());
            }
            return voiceNotifyService.sendBatchVoiceNotify(sendBatchVoiceNotify);
        } catch (IOException | URISyntaxException e) {
            logger.info("群发语音失败！phoneNumbers:%",sendBatchVoiceNotify.getPhoneNumberJson(),e);
            return new Result(ResultEnum.SYSTEM_EXCEPTION);
        }
    }


}
