package com.zehong.communication.service.impl;

import com.aliyun.dyvmsapi20170525.Client;
import com.aliyun.dyvmsapi20170525.models.SingleCallByTtsRequest;
import com.aliyun.dyvmsapi20170525.models.SingleCallByTtsResponse;
import com.aliyun.teaopenapi.models.Config;
import com.zehong.communication.common.result.Result;
import com.zehong.communication.common.result.ResultEnum;
import com.zehong.communication.model.SendAliVoiceNotify;
import com.zehong.communication.service.AliVoiceNotifyService;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

@Service
public class AliVoiceNotifyServiceImpl implements AliVoiceNotifyService{

    @Value("${accessKeyId}")
    private String accessKeyId;

    @Value("${accessKeySecret}")
    private String accessKeySecret;

    /**
     * 发送阿里语音
     * @param sendAliVoiceNotify 阿里语音
     * @return sendAliVoiceNotify
     */
    @Override
    public Result sendAliVoiceNotify(SendAliVoiceNotify sendAliVoiceNotify) throws Exception {
        com.aliyun.dyvmsapi20170525.Client client = createClient();
        SingleCallByTtsRequest singleCallByTtsRequest = new SingleCallByTtsRequest()
                .setCalledNumber(sendAliVoiceNotify.getCalledNumber())
                .setTtsCode(sendAliVoiceNotify.getTtsCode())
                .setTtsParam(sendAliVoiceNotify.getTtsParam());

        if(StringUtils.isNotBlank(sendAliVoiceNotify.getCalledShowNumber())){
            singleCallByTtsRequest.setCalledShowNumber(sendAliVoiceNotify.getCalledShowNumber());
        }

        if(sendAliVoiceNotify.getPlayTimes()>0){
            singleCallByTtsRequest.setPlayTimes(sendAliVoiceNotify.getPlayTimes());
        }

        if(sendAliVoiceNotify.getVolume() != -1){
            singleCallByTtsRequest.setVolume(sendAliVoiceNotify.getVolume());
        }

        if(sendAliVoiceNotify.getSpeed() != 555){
            singleCallByTtsRequest.setSpeed(sendAliVoiceNotify.getSpeed());
        }

        if(StringUtils.isNotBlank(sendAliVoiceNotify.getOutId())){
            singleCallByTtsRequest.setOutId(sendAliVoiceNotify.getOutId());
        }
        SingleCallByTtsResponse response = client.singleCallByTts(singleCallByTtsRequest);
        if(response.getBody().getCode() != null && "OK".equals(response.getBody().getCode())){
            //请求成功
            return new Result(ResultEnum.SUCCESS.getCode(),response.getBody().getMessage());
        }

        return new Result(ResultEnum.FAIL.getCode(),response.getBody().getMessage());
    }

    /**
     * 使用AK&SK初始化账号Client
     * @return Client
     * @throws Exception 异常
     */
    private Client createClient() throws Exception {
        Config config = new Config()
                // 您的AccessKey ID
                .setAccessKeyId(accessKeyId)
                // 您的AccessKey Secret
                .setAccessKeySecret(accessKeySecret);
        // 访问的域名
        config.endpoint = "dyvmsapi.aliyuncs.com";
        return new com.aliyun.dyvmsapi20170525.Client(config);
    }
}
